@@ -54,7 +54,8 @@ class BaseCacheMixin:
             point.flush_cache()
 
     def _get_cache_key(self):
-        return f'user{getattr(self._user, "id")}_{self._point_id.id}'
+        user_id = getattr(self._user, "id") if self._user is not None else 'none'
+        return f'user{user_id}_{self._point_id.id}'
 
     @property
     def _data_key(self):
